/* 
Purpose      : Create [dbo].[DimProductCategoryKPI] table and insert the values.
Author       : Julie Koesmarno
Date Created : 27 November 2014
Note         : 
  Please use the following script in conjunction with the instruction mentioned on 
  http://www.mssqlgirl.com/dynamic-kpi-treshold-in-tabular-or-power-pivot.html
Disclaimer   :
  This script is provided AS IS without warranty of any kind. Please use this script at your own discretion.
*/

USE [AdventureWorksDW2008R2]
GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE TABLE [dbo].[DimProductCategoryKPI](
	[ProductCategoryKPIID] [smallint] IDENTITY(1,1) NOT NULL,
	[ProductCategoryKey] [int] NOT NULL,
	[StartDate] [date] NOT NULL,
	[EndDate] [date] NOT NULL,
	[IsGreenYellowRed] [bit] NOT NULL,
	[YellowStart] [decimal](10, 5) NOT NULL,
	[YellowEnd] [decimal](10, 5) NOT NULL,
	[TargetSalesAmount] [money] NOT NULL,
 CONSTRAINT [PK_DimProductCategoryKPI] PRIMARY KEY CLUSTERED 
(
	[ProductCategoryKPIID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

ALTER TABLE [dbo].[DimProductCategoryKPI]  WITH CHECK ADD  CONSTRAINT [FK_DimProductCategoryKPI_DimProductCategory] FOREIGN KEY([ProductCategoryKey])
REFERENCES [dbo].[DimProductCategory] ([ProductCategoryKey])
GO

ALTER TABLE [dbo].[DimProductCategoryKPI] CHECK CONSTRAINT [FK_DimProductCategoryKPI_DimProductCategory]
GO

SET ANSI_PADDING OFF
GO


SET NOCOUNT ON;
SET XACT_ABORT ON;
GO

SET IDENTITY_INSERT [dbo].[DimProductCategoryKPI] ON;

BEGIN TRANSACTION;
INSERT INTO [dbo].[DimProductCategoryKPI]([ProductCategoryKPIID], [ProductCategoryKey], [StartDate], [EndDate], [IsGreenYellowRed], [YellowStart], [YellowEnd], [TargetSalesAmount])
SELECT 1, 1, '20050101', '20051231', 0, -0.2, -0.1, 3200000 UNION ALL
SELECT 2, 1, '20060101', '20061231', 0, -0.3, -0.1, 6000000 UNION ALL
SELECT 3, 1, '20070101', '20071231', 0, -0.1, -0.01, 9000000 UNION ALL
SELECT 4, 1, '20080101', '20081231', 0, -0.1, -0.01, 9300000 UNION ALL
SELECT 5, 3, '20070101', '20071231', 0, -0.2, -0.02, 138000 UNION ALL
SELECT 6, 3, '20080101', '20081231', 0, -0.1, -0.01, 201000 UNION ALL
SELECT 7, 4, '20070101', '20071231', 0, -0.1, -0.01, 450000 UNION ALL
SELECT 8, 4, '20080101', '20081231', 0, -0.1, -0.01, 450000

COMMIT;
RAISERROR (N'[dbo].[DimProductCategoryKPI]: Insert Batch: 1.....Done!', 10, 1) WITH NOWAIT;
GO

SET IDENTITY_INSERT [dbo].[DimProductCategoryKPI] OFF;

SELECT * FROM [dbo].[DimProductCategoryKPI]

